@@ -29,9 +29,10 @@ image_model_list = [
     # ImageModel(network_name="EfficientNetB0", batch_size=32 * 32, num_epochs=2, optimizer_params={'lr': 1})
 ]
 image_models = ImageModels(image_model_list=image_model_list)
-
-diamond_collector = run(images,
-                        labels,
+image_shape = (3, 32, 32)
+diamond_collector = run(images=images,
+                        image_shape=image_shape,
+                        labels=labels,
                         is_augment_data=False,
                         image_augmentation_info=ImagesAugmentationInfo(aug_prop=0.01),
                         is_train_model=True, image_models=image_models,
