@@ -29,7 +29,7 @@ class ImageModelTraining:
 
     def get_model(self):
         supported_models = ["EfficientNetB0", "EfficientNetB4", "EfficientNetB7", "ResNet50", "ResNet101",
-                            "DenseNet121"]
+                            "DenseNet121", "DenseNet161", "DenseNet201"]
         if self.image_model.network_name == "EfficientNetB0":
             model = hub.load('rwightman/pytorch-image-models', 'efficientnet_b0', pretrained=True)
         elif self.image_model.network_name == "EfficientNetB4":
@@ -42,6 +42,12 @@ class ImageModelTraining:
             model = models.resnet101(pretrained=True)
         elif self.image_model.network_name == "DenseNet121":
             model = models.densenet121(pretrained=True)
+        elif self.image_model.network_name == "DenseNet161":
+            model = models.densenet161(pretrained=True)
+        elif self.image_model.network_name == "DenseNet169":
+            model = models.densenet169(pretrained=True)
+        elif self.image_model.network_name == "DenseNet201":
+            model = models.densenet201(pretrained=True)
         else:
             raise ValueError(
                 f"Unsupported network name: {self.image_model.network_name}, please choose one of: {supported_models}")
