@@ -8,8 +8,9 @@ from diamond.user_classes import ImagesData, ImagesAugmentationInfo, ImageModels
 
 
 def run(images,
+        image_shape,
         labels=None,
-        validation_prop=0.2,
+        validation_prop=0.3,
         is_augment_data=True, image_augmentation_info=None,
         is_train_model=True, image_models=None,
         is_post_model_analysis=True, image_post_model: ImagePostModelSpec = None,
@@ -23,15 +24,12 @@ def run(images,
     print(story)
     diamond_collector = {}
 
-    # load the data
-    images = images.reshape(-1, 3, 32, 32)
-
     if labels is None:
         is_train_model = False
         pass  # TODO: create labels of 1s
 
     # Image data
-    image_data = ImagesData(images=images, labels=labels, validation_prop=validation_prop)
+    image_data = ImagesData(images=images, labels=labels, validation_prop=validation_prop, image_shape=image_shape)
     diamond_collector["image_data"] = image_data
     # plot
     if plot:
