@@ -8,13 +8,20 @@ from tqdm import tqdm
 
 
 class ImagesData:
-    def __init__(self, images, labels, validation_prop):
+    def __init__(self, images, labels, validation_prop, image_shape):
         self.images = images
         self.labels = labels
         self.validation_prop = validation_prop
+        self.image_shape = image_shape
         self.problem_type = self.get_problem_type()
+        # reshape
+        self.images = self.images.reshape((-1,) + self.image_shape)
+        self.is_colored = True if len(self.image_shape) > 2 else False
+        if self.is_colored:
+            self.images_to_show = np.transpose(self.images, (0, 2, 3, 1))
+        else:
+            self.images_to_show = np.transpose(self.images, (0, 1, 2))
         self.images_train, self.labels_train, self.images_val, self.labels_val = self.split()
-        self.images_to_show = np.transpose(images, (0, 2, 3, 1))
 
     def split(self):
         assert 0 <= self.validation_prop < 0.8, "validation proportion should be in range (0, 0.8)"
@@ -81,20 +88,19 @@ class ImageModel:
     def __init__(self,
                  network_name="EfficientNetB0",
                  remove_num_last_layers=1,
-                 batch_size=32,
-                 num_epochs=2,
+                 batch_size=64,
+                 num_epochs=3,
                  optimizer_params=None,
-                 dropout=0.7
+                 dropout=0.5
                  ):
         self.network_name = network_name
-        # TODO: validate network_name name!
         self.remove_last_layers_num = remove_num_last_layers
         self.batch_size = batch_size
         self.num_epochs = num_epochs
         self.optimizer_params = optimizer_params
         self.dropout = dropout
         if self.optimizer_params is None:
-            self.optimizer_params = {"lr": 0.01, 'weight_decay': 0.0001}
+            self.optimizer_params = {"lr": 0.001, 'weight_decay': 0.0001}
         self.network_parameters = self.optimizer_params.copy()
         self.network_parameters["_model_name"] = self.network_name
         self.network_parameters["_num_epochs"] = self.num_epochs
